from PySide import QtGui
from PySide import QtCore

replaceDict = {'pi': '3.1415926535897932384', '/': './', '*': '.*'}


### STYLE ###

blueLabel = '''
        QLabel {
            color:rgb(78, 157, 213);
        }
        '''

blueLineEdit = '''
        QLineEdit {
            border-style: solid;
            border-width: 2px;
            border-color:rgb(48, 127, 183);
            border-radius:5px;
            color:rgb(48, 127, 183);
        }
        QLineEdit:focus {
            color:rgb(78, 157, 213);
            border-color:rgb(78, 157, 213);
        }
        '''
redLineEdit = '''
        QLineEdit {
            border-style: solid;
            border-width: 2px;
            border-color:rgb(224, 78, 62);
            border-radius:5px;
            color:rgb(224, 78, 62);
        }
        QLineEdit:hover {
            border-width: 0px;
            background-color:rgb(224, 78, 62);
            color:rgb(50, 50, 50);
        }
        '''
blueBtn = '''
        QPushButton {
            background:none;
            border-style: solid;
            border-width: 2px;
            border-color:rgb(48, 127, 183);
            border-radius:5px;
            color:rgb(48, 127, 183);
        }
        QPushButton:hover {
            border-width: 0px;
            background-color:rgb(48, 127, 183);
            color:rgb(50, 50, 50);
        }
        '''
redBtn = '''
        QPushButton {
            background:none;
            border-style: solid;
            border-width: 2px;
            border-color:rgb(224, 78, 62);
            border-radius:5px;
            color:rgb(224, 78, 62);
            transition: color 2s;
        }
        QPushButton:hover {
            transition: color 2s;
            border-width: 0px;
            background-color:rgb(224, 78, 62);
            color:rgb(50, 50, 50);
        }
        '''

### CLASS ###

class Calculator(QtGui.QDialog):

    def __init__(self):
        super(Calculator, self).__init__()

        self.setWindowTitle('Calculator')
        self.setFixedSize(300,190)

        # CSS
        self.goodTxtLineCss = 'background-color:rgb(50, 50, 50);'
        self.errorTxtLineCss = 'background-color:rgb(224, 78, 62);'

    def createLayout(self):

        self.mainLayout = QtGui.QVBoxLayout()

        self.lineLayout = QtGui.QVBoxLayout()
        self.buttonLayout = QtGui.QHBoxLayout()

    def createWidget(self):

        self.operationLabel = QtGui.QLabel('Operation :')
        self.operationLabel.setStyleSheet(blueLabel)
        self.operationTxt = QtGui.QLineEdit()
        self.operationTxt.setStyleSheet(blueLineEdit)
        self.operationTxt.setFixedHeight(25)

        # Font
        self.resultFont = QtGui.QFont()
        self.resultFont.setPixelSize(20)
        self.resultFont.setBold(True)

        self.resultTxt = QtGui.QLineEdit()
        self.resultTxt.setStyleSheet(blueLineEdit)
        self.resultTxt.setFixedHeight(65)
        self.resultTxt.setAlignment(QtCore.Qt.AlignCenter)
        self.resultTxt.setDisabled(True)
        self.resultTxt.setFont(self.resultFont)


        self.calculateBtn = QtGui.QPushButton('Result')
        self.calculateBtn.setFixedHeight(30)
        self.calculateBtn.setStyleSheet(blueBtn)

        self.cancelBtn = QtGui.QPushButton('Cancel')
        self.cancelBtn.setFixedHeight(30)
        self.cancelBtn.setStyleSheet(redBtn)


    def addWidgetToLayout(self):


        self.lineLayout.addWidget(self.resultTxt)
        self.lineLayout.addWidget(self.operationLabel)
        self.lineLayout.addWidget(self.operationTxt)

        self.buttonLayout.addWidget(self.calculateBtn)
        self.buttonLayout.addWidget(self.cancelBtn)

    def layoutHierarchy(self):

        self.mainLayout.addLayout(self.lineLayout)
        self.mainLayout.addLayout(self.buttonLayout)

        self.setLayout(self.mainLayout)

    def createConnection(self):

        self.calculateBtn.clicked.connect(self.calculate)
        self.operationTxt.returnPressed.connect(self.calculate)
        self.cancelBtn.clicked.connect(self.cancelUi)


    def calculate(self):

        self.resultTxt.setText('')

        operation = str(self.operationTxt.text())

        if operation:
            nothing = False
            for key in replaceDict.iterkeys():
                splitDivide = operation.split(key)
                if len(splitDivide) > 1:
                    newOperation = str(replaceDict[key]).join(splitDivide)
                    try:
                        eval(newOperation)
                        operation = newOperation
                        nothing = False
                    except:
                        operation = operation
                if nothing:
                    operation = str(self.operationTxt.text())

            print 'Operation : ', operation

            try:
                result = str(eval(operation))
                print 'Result : ',result
                self.resultTxt.setText(result)
                self.resultTxt.setStyleSheet(blueLineEdit)
                self.resultTxt.setDisabled(False)
            except:
                self.resultTxt.setText('Operation Error')
                self.resultTxt.setStyleSheet(redLineEdit)
                self.resultTxt.setDisabled(True)

        else:
            self.resultTxt.setText('No operation')
            self.resultTxt.setStyleSheet(redLineEdit)
            self.resultTxt.setDisabled(True)

    def displayUi(self):

        self.createLayout()
        self.createWidget()
        self.addWidgetToLayout()
        self.layoutHierarchy()
        self.createConnection()

        self.show()

    def cancelUi(self):
        self.close()

calculator = Calculator()
calculator.displayUi()